@@ -354,6 +354,9 @@ class irtt_start(object):
         # 3: Re-Schedule
         tt = tod.tod(u'now')+tod.tod(u'0.01')
         while self.nc < tt:	# ensure interval is positive
+            if tod.MAX - tt < tod.ONE:
+                self.log.debug(u'Midnight rollover.')
+                break
             self.log.debug(u'May have missed an interval, catching up.')
             self.nc += tod.ONE	# 0.01 allows for processing delay
         ival = int(1000.0 * float((self.nc - tod.tod(u'now')).timeval))
