@@ -66,8 +66,8 @@ COL_SPLITS = 9
 # scb consts
 SCB_NAME_WIDTH = metarace.SCB_LINELEN - 9
 SCB_RESNAME_WIDTH = metarace.SCB_LINELEN - 11
-SCB_RESULT_FMT = [(2, 'l'), (3, 'r'), ' ',
-                  (SCB_RESNAME_WIDTH, 'l'), ' ', (4, 'r')]
+SCB_RESULT_FMT = [(2, u'l'), (3, u'r'), u' ',
+                  (SCB_RESNAME_WIDTH, u'l'), u' ', (4, u'r')]
 
 # scb function key mappings
 key_reannounce = 'F4'		     # (+CTRL) calls into delayed announce
@@ -159,13 +159,14 @@ class ittt(object):
             if r[COL_PLACE] is not None and r[COL_PLACE] != '':
                 if r[COL_PLACE].isdigit() and int(r[COL_PLACE]) > 20:
                     break
-                fmtplaces.append([r[COL_PLACE], r[COL_BIB],
-                                  strops.fitname(r[COL_FIRSTNAME],
-                                  r[COL_LASTNAME], SCB_RESNAME_WIDTH),
-                                  r[COL_CLUB]])
+                fmtplaces.append([r[COL_PLACE].decode('utf-8'),
+                          r[COL_BIB].decode('utf-8'),
+                          strops.fitname(r[COL_FIRSTNAME].decode('utf-8'),
+                          r[COL_LASTNAME].decode('utf-8'), SCB_RESNAME_WIDTH),
+                          r[COL_CLUB].decode('utf-8')])
         self.meet.scbwin = scbwin.scbtable(self.meet.scb,
                        self.meet.racenamecat(self.event),
-                       SCB_RESULT_FMT, fmtplaces, delay=90)
+                       SCB_RESULT_FMT, fmtplaces, delay=80)
         self.meet.scbwin.reset()
 
     def todstr(self, col, cr, model, iter, data=None):
@@ -181,7 +182,7 @@ class ittt(object):
                 cr.set_property('style', pango.STYLE_NORMAL)
             cr.set_property('text', (ft - st).rawtime(3))
         else:
-            cr.set_property('text', '')
+            cr.set_property('text', u'')
 
     def loadconfig(self):
         """Load race config from disk."""
@@ -230,6 +231,7 @@ class ittt(object):
                                         'bsbib':'',
                                         'bsstat':'idle',
                                         'showinfo':'Yes',
+                                        'showcats':'No',
                                         'distance':defdistance,
 					'distunits':defdistunits,
                                         'chan_S':defchans,
@@ -256,6 +258,7 @@ class ittt(object):
         self.autoarm = strops.confopt_bool(cr.get('event', 'autoarm'))
         self.info_expand.set_expanded(strops.confopt_bool(
                                        cr.get('event', 'showinfo')))
+        self.showcats = strops.confopt_bool(cr.get('event', 'showcats'))
         self.inomnium = strops.confopt_bool(cr.get('event', 'inomnium'))
         if self.inomnium:
             # SWITCH: Event is part of an omnium, make any req'd overrides
@@ -329,8 +332,8 @@ class ittt(object):
         # an appropriate outcome.
         eid = cr.get('event', 'id')
         if eid and eid != EVENT_ID:
-            self.log.error('Event configuration mismatch: '
-                           + repr(eid) + ' != ' + repr(EVENT_ID))
+            self.log.error(u'Event configuration mismatch: '
+                           + repr(eid) + u' != ' + repr(EVENT_ID))
             self.readonly = True
 
     def saveconfig(self):
@@ -350,6 +353,7 @@ class ittt(object):
         cw.set('event', 'chan_A', self.chan_A)
         cw.set('event', 'chan_B', self.chan_B)
         cw.set('event', 'autoarm', self.autoarm)
+        cw.set('event', 'showcats', self.showcats)
         cw.set('event', 'startlist', self.get_startlist())
         cw.set('event', 'inomnium', self.inomnium)
         cw.set('event', 'showinfo', self.info_expand.get_expanded())
@@ -393,13 +397,20 @@ class ittt(object):
         if self.timetype == 'single':
             sec.set_single()
 
-        sec.heading = ' '.join([
-                      'Event', self.evno, ':',
-                  self.meet.edb.getvalue(self.event, eventdb.COL_PREFIX),
-                  self.meet.edb.getvalue(self.event, eventdb.COL_INFO),
-                      '- Start List'])
+        sec.heading = u' '.join([
+                      u'Event', self.evno, u':',
+                      self.event[u'pref'], self.event[u'info'],
+                      u'- Start List'])
+        lapstring = strops.lapstring(self.event[u'laps'])
+        substr = u' '.join([lapstring, self.event[u'dist'],
+                             self.event[u'prog']]).strip()
+        if substr:
+            sec.subheading = substr
+        if self.event[u'reco']:
+            sec.recordstr = self.event[u'reco']
         sec.lines = self.get_heats()
-        return sec
+        ret.append(sec)
+        return ret
 
     def sort_startlist(self, x, y):
         """Comparison function for ttt seeding."""
@@ -444,7 +455,7 @@ class ittt(object):
             count = placeholders
             miss = 2000
             while len(self.riders) < count:
-                self.addrider(str(miss))	# WARNING!
+                self.addrider(unicode(miss))	# WARNING!
                 miss += 1
         blanknames = False	# HACK!!
         if placeholders > 0:
@@ -452,12 +463,14 @@ class ittt(object):
         if self.timetype == 'single':
             for r in self.riders:
                 rno = r[COL_BIB]
+                if u't' in self.series:	# Team no hack
+                    rno = u' '	# force name
                 rname = strops.resname(r[COL_FIRSTNAME], r[COL_LASTNAME],
                                        r[COL_CLUB])
                 info = None
                 if cats and rno in cats:
                     info = cats[rno]
-                hlist.append([str(count)+'.1', rno, rname, info])
+                hlist.append([unicode(count)+'.1', rno, rname, info])
                                  # all heats are one up
                 count -= 1
         else:
@@ -465,11 +478,11 @@ class ittt(object):
             lane = 1
             for r in self.riders:
                 rno = r[COL_BIB]
-                if 't' in self.series:	# Team no hack
-                    rno = ' '	# force name
+                if u't' in self.series:	# Team no hack
+                    rno = u' '	# force name
                 rname = strops.resname(r[COL_FIRSTNAME], r[COL_LASTNAME],
                                    r[COL_CLUB])
-                heat = str(hno) + '.' + str(lane)
+                heat = unicode(hno) + u'.' + unicode(lane)
                 info = None
                 if cats and rno in cats:
                     info = cats[rno]
@@ -493,10 +506,10 @@ class ittt(object):
                 rec = []
             heat = str(h)
             if self.difftime:	# override heat if 'final'
-                heat = '-'
+                heat = u'-'
             if blanknames:
-                r[1] = ''
-                r[2] = ''
+                r[1] = u''
+                r[2] = u''
                 r[3] = None
             rec.extend([heat, r[1], r[2], r[3]])
             lcnt += 1
@@ -510,72 +523,73 @@ class ittt(object):
         ret = []
         for r in self.riders:
             ret.append(r[COL_BIB])
-        return ' '.join(ret)
+        return u' '.join(ret)
 
     def delayed_announce(self):
         """Initialise the announcer's screen after a delay."""
         if self.winopen:
             self.meet.announce.clrall()
-            self.meet.ann_title(' '.join([
-                  'Event', self.evno, ':',
-                  self.meet.edb.getvalue(self.event, eventdb.COL_PREFIX),
-                  self.meet.edb.getvalue(self.event, eventdb.COL_INFO)]))
+            self.meet.ann_title(u' '.join([
+                  u'Event', self.evno, u':',
+                  self.event[u'pref'], self.event[u'info']]))
 
-            self.meet.announce.linefill(1, '_')
-            self.meet.announce.linefill(7, '_')
+            self.meet.announce.linefill(1, u'_')
+            self.meet.announce.linefill(7, u'_')
 
             # fill in front straight
             fbib = self.fs.getrider()
-            if fbib is not None and fbib != '':
+            if fbib is not None and fbib != u'':
                 r = self.getrider(fbib)
                 if r is not None:
-                    clubstr = ''
-                    if r[COL_CLUB] != '' and len(r[COL_CLUB]) <= 3:
-                        clubstr = '(' + r[COL_CLUB] + ')'
+                    clubstr = u''
+                    if r[COL_CLUB] != u'' and len(r[COL_CLUB]) <= 3:
+                        clubstr = u'(' + r[COL_CLUB] + u')'
                     namestr = strops.fitname(r[COL_FIRSTNAME],
                                              r[COL_LASTNAME], 24, trunc=True)
-                    placestr = '   ' # 3 ch
-                    if r[COL_PLACE] != '':
-                        placestr = strops.truncpad(r[COL_PLACE] + '.', 3)
-                    bibstr = strops.truncpad(r[COL_BIB], 3, 'r')
-                    tmstr = ''
+                    placestr = u'   ' # 3 ch
+                    if r[COL_PLACE] != u'':
+                        placestr = strops.truncpad(r[COL_PLACE] + u'.', 3)
+                    bibstr = strops.truncpad(r[COL_BIB], 3, u'r')
+                    tmstr = u''
                     if r[COL_START] is not None and r[COL_FINISH] is not None:
                         tmstr = (r[COL_FINISH] - r[COL_START]).rawtime(3)
-                    cmtstr = ''
-                    if r[COL_COMMENT] is not None and r[COL_COMMENT] != '':
+                    cmtstr = u''
+                    if r[COL_COMMENT] is not None and r[COL_COMMENT] != u'':
                         cmtstr = strops.truncpad(
-                                 '[' + r[COL_COMMENT].strip() + ']', 38, 'r')
-                    self.meet.announce.postxt(3,0,'        Front Straight')
-                    self.meet.announce.postxt(4,0,' '.join([placestr, bibstr,
+                              u'[' + r[COL_COMMENT].strip() + u']', 38, u'r')
+                    self.meet.announce.postxt(3,0,u'        Front Straight')
+                    self.meet.announce.postxt(4,0,u' '.join([placestr, bibstr,
                                                          namestr, clubstr]))
-                    self.meet.announce.postxt(5,26,strops.truncpad(tmstr, 12, 'r'))
+                    self.meet.announce.postxt(5,26,strops.truncpad(tmstr,
+                                                                  12, u'r'))
                     self.meet.announce.postxt(6,0,cmtstr)
 
             # fill in back straight
             bbib = self.bs.getrider()
-            if bbib is not None and bbib != '':
+            if bbib is not None and bbib != u'':
                 r = self.getrider(bbib)
                 if r is not None:
-                    clubstr = ''
-                    if r[COL_CLUB] != '' and len(r[COL_CLUB]) <= 3:
-                        clubstr = '(' + r[COL_CLUB] + ')'
+                    clubstr = u''
+                    if r[COL_CLUB] != u'' and len(r[COL_CLUB]) <= 3:
+                        clubstr = u'(' + r[COL_CLUB] + u')'
                     namestr = strops.fitname(r[COL_FIRSTNAME],
                                              r[COL_LASTNAME], 24, trunc=True)
-                    placestr = '   ' # 3 ch
-                    if r[COL_PLACE] != '':
-                        placestr = strops.truncpad(r[COL_PLACE] + '.', 3)
-                    bibstr = strops.truncpad(r[COL_BIB], 3, 'r')
-                    tmstr = ''
+                    placestr = u'   ' # 3 ch
+                    if r[COL_PLACE] != u'':
+                        placestr = strops.truncpad(r[COL_PLACE] + u'.', 3)
+                    bibstr = strops.truncpad(r[COL_BIB], 3, u'r')
+                    tmstr = u''
                     if r[COL_START] is not None and r[COL_FINISH] is not None:
                         tmstr = (r[COL_FINISH] - r[COL_START]).rawtime(3)
-                    cmtstr = ''
-                    if r[COL_COMMENT] is not None and r[COL_COMMENT] != '':
+                    cmtstr = u''
+                    if r[COL_COMMENT] is not None and r[COL_COMMENT] != u'':
                         cmtstr = strops.truncpad(
-                                 '[' + r[COL_COMMENT].strip() + ']', 38, 'r')
-                    self.meet.announce.postxt(3,42,'        Back Straight')
-                    self.meet.announce.postxt(4,42,' '.join([placestr, bibstr,
+                             u'[' + r[COL_COMMENT].strip() + u']', 38, u'r')
+                    self.meet.announce.postxt(3,42,u'        Back Straight')
+                    self.meet.announce.postxt(4,42,u' '.join([placestr, bibstr,
                                                          namestr, clubstr]))
-                    self.meet.announce.postxt(5,68,strops.truncpad(tmstr, 12, 'r'))
+                    self.meet.announce.postxt(5,68,strops.truncpad(tmstr,
+                                                12, u'r'))
                     self.meet.announce.postxt(6,42,cmtstr)
 
             # fill in leaderboard/startlist
@@ -588,21 +602,21 @@ class ittt(object):
                     curline = 9
                     posoft = 42
 
-                clubstr = ''
-                if r[COL_CLUB] != '' and len(r[COL_CLUB]) <= 3:
-                    clubstr = ' (' + r[COL_CLUB] + ')'
+                clubstr = u''
+                if r[COL_CLUB] != u'' and len(r[COL_CLUB]) <= 3:
+                    clubstr = u' (' + r[COL_CLUB] + u')'
  
                 namestr = strops.truncpad(strops.fitname(r[COL_FIRSTNAME],
                               r[COL_LASTNAME], 20-len(clubstr))+clubstr, 20)
-                placestr = '   ' # 3 ch
-                if r[COL_PLACE] != '':
-                    placestr = strops.truncpad(r[COL_PLACE] + '.', 3)
-                bibstr = strops.truncpad(r[COL_BIB], 3, 'r')
-                tmstr = '         ' # 9 ch
+                placestr = u'   ' # 3 ch
+                if r[COL_PLACE] != u'':
+                    placestr = strops.truncpad(r[COL_PLACE] + u'.', 3)
+                bibstr = strops.truncpad(r[COL_BIB], 3, u'r')
+                tmstr = u'         ' # 9 ch
                 if r[COL_START] is not None and r[COL_FINISH] is not None:
                     tmstr = strops.truncpad(
-                           (r[COL_FINISH] - r[COL_START]).rawtime(3), 9, 'r')
-                self.meet.announce.postxt(curline, posoft, ' '.join([
+                           (r[COL_FINISH] - r[COL_START]).rawtime(3), 9, u'r')
+                self.meet.announce.postxt(curline, posoft, u' '.join([
                       placestr, bibstr, namestr, tmstr]))
                 curline += 1
 
@@ -718,21 +732,32 @@ class ittt(object):
 
     def result_report(self):
         """Return a list of printing sections containing the race result."""
+        self.placexfer()
         ret = []
         sec = printing.section()
-        sec.heading = 'Event ' + self.evno + ': ' + ' '.join([
-                       self.meet.edb.getvalue(self.event, eventdb.COL_PREFIX),
-                       self.meet.edb.getvalue(self.event, eventdb.COL_INFO)
+        sec.heading = u'Event ' + self.evno + u': ' + u' '.join([
+                       self.event[u'pref'], self.event[u'info']
                               ]).strip()
+        lapstring = strops.lapstring(self.event[u'laps'])
+        substr = u' '.join([lapstring, self.event[u'dist'],
+                             self.event[u'prog']]).strip()
+        if substr:
+            sec.subheading = substr
         sec.lines = []
         ftime = None
         for r in self.riders:
             rno = r[COL_BIB]
+            if u't' in self.series:	# Team no hack
+                rno = u' '	# force name
             rank = None
             rname = strops.resname(r[COL_FIRSTNAME], r[COL_LASTNAME],
                                       r[COL_CLUB])
             rtime = None
             rcat = None
+            if self.showcats:
+                dbr = self.meet.rdb.getrider(rno, self.series)
+                if dbr is not None:
+                    rcat = self.meet.rdb.getvalue(dbr, riderdb.COL_CAT)
             info = None
             dtime = None
             if self.onestart:
@@ -747,74 +772,23 @@ class ittt(object):
                         ftime = time
                     else:
                         dtime = '+' + (time - ftime).rawtime(2)
-                    rtime = time.rawtime(3)
+                    if r[COL_START] != tod.tod('0'):	# auto time
+                        rtime = time.rawtime(3)
+                    else:
+                        rtime = time.rawtime(2) + ' '
                 elif r[COL_COMMENT]:
                     rtime = str(r[COL_COMMENT])
 
-            sec.lines.append([rank, rno, rname, None, rtime, dtime])
+            sec.lines.append([rank, rno, rname, rcat, rtime, dtime])
         ret.append(sec)
         return ret
 
-    def result_export(self, f):
-        """Export results to supplied file handle."""
-        cr = csv.writer(f)
-        df = ''
-        dist = self.meet.get_distance(self.distance, self.units)
-        if dist:
-            df = str(dist) + 'm'
-        header = ['Event ' + self.evno, '', ' '.join([
-                       self.meet.edb.getvalue(self.event, eventdb.COL_PREFIX),
-                       self.meet.edb.getvalue(self.event, eventdb.COL_INFO)
-                              ]).strip(), '',df]
-        nsplits = len(self.splits)
-        if nsplits > 0:
-            for i in range(0, nsplits+1): # last lap is not saved in splits
-                header.append('Lap ' + str(i+1))
-        cr.writerow(header)
-        for r in self.riders:
-            rno = r[COL_BIB]
-            rname = strops.resname(r[COL_FIRSTNAME], r[COL_LASTNAME],
-                                      r[COL_CLUB])
-            plstr = r[COL_PLACE]
-            if plstr != '':
-                plstr = "'" + plstr
-                if r[COL_PLACE].isdigit():
-                    plstr += '.'
-            if r[COL_PLACE] != '' or r[COL_COMMENT] != '':
-                if r[COL_START] is None:
-                    r[COL_START] = tod.tod(0)
-                elap = ''
-                if r[COL_FINISH] is not None:
-                    elap = (r[COL_FINISH]-r[COL_START]).rawtime(3)
-                cmt = r[COL_COMMENT]
-                #if cmt == '':
-                    #dbr = self.meet.rdb.getrider(r[COL_BIB], self.series)
-                    #if dbr is not None:
-                        #cmt = self.meet.rdb.getvalue(dbr,
-                                                   #riderdb.COL_CAT)
-                resrow = [plstr,rno, rname, cmt, "'" + elap]
-                lt = r[COL_START]
-                for st in r[COL_SPLITS]:
-                    if st is not None:
-                        resrow.append("'"
-                                 + (st-lt).rawtime(2)) # lap
-                        lt = st
-                    else:
-                        resrow.append('')	# lap
-                if lt != r[COL_START] and r[COL_FINISH] is not None:
-                    # avoid degenerate split or abort/catch
-                    resrow.append("'"
-                       + (r[COL_FINISH]-lt).rawtime(2)) # lap
-                cr.writerow(resrow)
-            else:
-                cr.writerow([plstr,rno,rname,'',''])
-
     def editent_cb(self, entry, col):
         """Shared event entry update callback."""
-        if col == eventdb.COL_PREFIX:
-            self.meet.edb.editevent(self.event, prefix=entry.get_text())
-        elif col == eventdb.COL_INFO:
-            self.meet.edb.editevent(self.event, info=entry.get_text())
+        if col == u'pref':
+            self.event[u'pref'] = entry.get_text().decode('utf-8', 'replace')
+        elif col == u'info':
+            self.event[u'info'] = entry.get_text().decode('utf-8', 'replace')
         self.update_expander_lbl_cb()
 
     def update_expander_lbl_cb(self):
@@ -878,12 +852,14 @@ class ittt(object):
         if self.timerwin and type(self.meet.scbwin) is scbwin.scbtt:
             place = self.riders.get_value(ri, COL_PLACE)
             if sp is self.fs:
+                elap = t - self.curstart
+                self.meet.gemini.rtick(elap)	## DANGER -> TEST
                 self.meet.scbwin.setr1('(' + place + ')')
                 self.meet.scbwin.sett1(self.fs.ck.get_text())
                 if self.timetype == 'single': # Speed/TTB is hack mode
                     dist = self.meet.get_distance(self.distance, self.units)
                     if dist is not None:
-                        spstr = (t - self.curstart).speedstr(dist).strip()
+                        spstr = elap.speedstr(dist).strip()
                         glib.timeout_add_seconds(1, self.clear_200_ttb,
                                                     self.meet.scbwin,
                                                     'Avg:',
@@ -896,6 +872,9 @@ class ittt(object):
                 self.meet.scbwin.sett2(self.bs.ck.get_text())
         # call for a delayed announce...
         glib.idle_add(self.delayed_announce)
+        # AND THEN, if other lane not armed, export result
+        if self.t_other(sp).getstatus() != 'armfin':
+            self.meet.delayed_export()
 
     def timercb(self, e):
         """Handle a timer event."""
@@ -924,9 +903,11 @@ class ittt(object):
             return False
         now = tod.tod('now')
         if self.fs.status in ['running', 'armint', 'armfin']:
-            self.fs.runtime(now - self.lstart)
+            elap = now - self.lstart
+            self.fs.runtime(elap)
             if self.timerwin and type(self.meet.scbwin) is scbwin.scbtt:
                 self.meet.scbwin.sett1(self.fs.ck.get_text())
+                self.meet.gemini.rtick(elap, 1)
         if self.bs.status in ['running', 'armint', 'armfin']:
             self.bs.runtime(now - self.lstart)
             if self.timerwin and type(self.meet.scbwin) is scbwin.scbtt:
@@ -1079,7 +1060,6 @@ class ittt(object):
         # if reqd, do places
         if doplaces:
             self.placexfer()
-            self.meet.delayed_export()
 
     def insert_split(self, i, st, bib):
         """Insert rider split into correct lap."""
@@ -1159,7 +1139,7 @@ class ittt(object):
                 # but continue by default - manual abort to override.
             glib.idle_add(self.delayed_announce)
         else:
-            self.log.warn('Unable to catch with single rider.')
+            self.log.warn(u'Unable to catch with single rider.')
 
     def falsestart(self):
         """Register false start."""
@@ -1181,6 +1161,7 @@ class ittt(object):
             self.toidle(idletimers=False)
         elif self.timerstat == 'armstart':
             if self.timerwin and type(self.meet.scbwin) is scbwin.scbtt:
+                self.meet.gemini.clear()
                 self.meet.scbwin.sett1('            ')
                 self.meet.scbwin.sett2('            ')
             self.toload()
@@ -1215,12 +1196,18 @@ class ittt(object):
             name = '[New Rider]'
             r = self.getrider(bib)
             if r is not None and r[COL_BIB] != '':
-                name = strops.fitname(r[COL_FIRSTNAME], r[COL_LASTNAME],
+                first = r[COL_FIRSTNAME].decode('utf-8')
+                last = r[COL_LASTNAME].decode('utf-8')
+                club = r[COL_CLUB].decode('utf-8')
+                name = strops.fitname(first,
+                                      last,
                                       SCB_NAME_WIDTH)
+                tp.namevec = [bib, strops.resname(first, last, club), '']
             return ' '.join([strops.truncpad(r[COL_BIB], 3, 'r'),
                              strops.truncpad(name, SCB_NAME_WIDTH),
-                             strops.truncpad(r[COL_CLUB], 3, 'r')])
+                             strops.truncpad(club, 3, 'r')])
         else:
+            tp.namevec = None
             return ''
         
     def showtimerwin(self):
@@ -1230,6 +1217,14 @@ class ittt(object):
                                 self.meet.racenamecat(self.event),
                                 self.fmtridername(self.fs),
                                 self.fmtridername(self.bs))
+        self.meet.gemini.reset_fields()
+        self.meet.announce.gfx_overlay(2)
+        self.meet.announce.gfx_set_title(self.event[u'pref'] + u' '
+                            + self.event[u'info'])
+        if self.fs.namevec is not None:
+            self.meet.announce.gfx_add_row(self.fs.namevec)
+        if self.bs.namevec is not None:
+            self.meet.announce.gfx_add_row(self.bs.namevec)
         self.timerwin = True
         self.meet.scbwin.reset()
 
@@ -1463,14 +1458,14 @@ class ittt(object):
         """Constructor."""
         self.meet = meet
         self.event = event      # Note: now a treerowref
-        self.evno = meet.edb.getvalue(event, eventdb.COL_EVNO)
-        self.evtype = meet.edb.getvalue(event, eventdb.COL_TYPE)
-        self.series = meet.edb.getvalue(event, eventdb.COL_SERIES)
+        self.evno = event[u'evid']
+        self.evtype = event[u'type']
+        self.series = event[u'seri']
         self.configpath = meet.event_configfile(self.evno)
 
         self.log = logging.getLogger('ittt')
         self.log.setLevel(logging.DEBUG)
-        self.log.debug('Creating new ittt event: ' + str(self.evno))
+        self.log.debug(u'Creating new ittt event: ' + self.evno)
 
         # properties
         self.autospec = ''	# automatic startlist
@@ -1483,6 +1478,8 @@ class ittt(object):
         self.chan_A = timy.CHAN_PA	# default is ITT/Pursuit
         self.chan_B = timy.CHAN_PB
         self.chan_S = timy.CHAN_START
+        self.fsvec = None
+        self.bsvec = None
 
         # race run time attributes
         self.autospec = ''
@@ -1492,6 +1489,7 @@ class ittt(object):
         self.readonly = not ui
         self.winopen = ui
         self.timerwin = False
+        self.showcats = False
         self.timerstat = 'idle'
         self.curstart = None
         self.lstart = None
@@ -1522,15 +1520,11 @@ class ittt(object):
         b.get_object('race_info_evno').set_text(self.evno)
         self.showev = b.get_object('race_info_evno_show')
         self.prefix_ent = b.get_object('race_info_prefix')
-        self.prefix_ent.connect('changed', self.editent_cb,
-                                 eventdb.COL_PREFIX)
-        self.prefix_ent.set_text(self.meet.edb.getvalue(
-                   self.event, eventdb.COL_PREFIX))
+        self.prefix_ent.connect('changed', self.editent_cb,u'pref')
+        self.prefix_ent.set_text(self.event[u'pref'])
         self.info_ent = b.get_object('race_info_title')
-        self.info_ent.connect('changed', self.editent_cb,
-                               eventdb.COL_INFO)
-        self.info_ent.set_text(self.meet.edb.getvalue(
-                   self.event, eventdb.COL_INFO))
+        self.info_ent.connect('changed', self.editent_cb,u'info')
+        self.info_ent.set_text(self.event[u'info'])
         self.type_lbl = b.get_object('race_type')
 
         # Timer Panes
