@@ -221,6 +221,24 @@ class fakemeet:
     def get_distance(self):
         return self.distance
 
+    def report_strings(self, rep):
+        """Copy the meet strings into the supplied report."""
+
+        ## this is a copy of meet.print_report()
+        rep.strings[u'title'] = self.title_str
+        rep.strings[u'subtitle'] = self.subtitle_str
+        rep.strings[u'docstr'] = self.document_str
+        rep.strings[u'datestr'] = strops.promptstr(u'Date:', self.date_str)
+        rep.strings[u'commstr'] = strops.promptstr(u'Chief Commissaire:',
+                                                  self.commissaire_str)
+        rep.strings[u'orgstr'] = strops.promptstr(u'Organiser:',
+                                                  self.organiser_str)
+        if self.distance:
+            rep.strings[u'diststr'] = strops.promptstr(u'Distance:',
+                                           unicode(self.distance) + u' km')
+        else:
+            rep.strings[u'diststr'] = u''
+
     def announce_cmd(self, ctype=None, cmsg=None):
         pass
     def announce_time(self, data=None):
@@ -241,6 +259,7 @@ class fakemeet:
                u'title':u'',
                u'shortname':u'',
                u'subtitle':u'',
+               u'document':u'',
                u'date':u'',
                u'organiser':u'',
                u'commissaire':u'',
@@ -262,6 +281,7 @@ class fakemeet:
         self.shortname = cr.get(u'meet', u'shortname')
         self.title_str = cr.get(u'meet', u'title')
         self.subtitle_str = cr.get(u'meet', u'subtitle')
+        self.document_str = cr.get(u'meet', u'document')
         self.date_str = cr.get(u'meet', u'date')
         self.organiser_str = cr.get(u'meet', u'organiser')
         self.commissaire_str = cr.get(u'meet', u'commissaire')
@@ -341,6 +361,8 @@ class roadmeet:
         t_ent.set_text(self.title_str)
         st_ent = b.get_object('subtitle_entry')
         st_ent.set_text(self.subtitle_str)
+        doc_ent = b.get_object('document_entry')
+        doc_ent.set_text(self.document_str)
         d_ent = b.get_object('date_entry')
         d_ent.set_text(self.date_str)
         o_ent = b.get_object('organiser_entry')
@@ -379,6 +401,7 @@ class roadmeet:
             self.log.debug(u'Updating meet properties.')
             self.title_str = t_ent.get_text().decode('utf-8')
             self.subtitle_str = st_ent.get_text().decode('utf-8')
+            self.document_str = doc_ent.get_text().decode('utf-8')
             self.date_str = d_ent.get_text().decode('utf-8')
             self.organiser_str = o_ent.get_text().decode('utf-8')
             self.commissaire_str = c_ent.get_text().decode('utf-8')
@@ -425,20 +448,18 @@ class roadmeet:
         else:
             self.window.unfullscreen()
 
-    def print_report(self, sections=[], subtitle=u'', docstr=u''):
+    def print_report(self, sections=[]):
         """Print the pre-formatted sections in a standard report."""
-        self.log.info(u'Printing report ' + repr(subtitle) + u'...')
-
         tfile = self.default_template()
         rep = printing.printrep(template=tfile, path=self.configpath)
         rep.strings[u'title'] = self.title_str
         rep.strings[u'subtitle'] = self.subtitle_str
+        rep.strings[u'docstr'] = self.document_str
         rep.strings[u'datestr'] = strops.promptstr(u'Date:', self.date_str)
         rep.strings[u'commstr'] = strops.promptstr(u'Chief Commissaire:',
                                                   self.commissaire_str)
         rep.strings[u'orgstr'] = strops.promptstr(u'Organiser:',
                                                   self.organiser_str)
-        rep.strings[u'docstr'] = docstr
         if self.distance:
             rep.strings[u'diststr'] = strops.promptstr(u'Distance:',
                                            unicode(self.distance) + u' km')
@@ -568,34 +589,30 @@ class roadmeet:
     def menu_reports_startlist_activate_cb(self, menuitem, data=None):
         """Generate a startlist."""
         if self.curevent is not None:
-            title = u'Startlist'
             sections = self.curevent.startlist_report()
             if sections:
-                self.print_report(sections, title, u'')
+                self.print_report(sections)
 
     def menu_reports_camera_activate_cb(self, menuitem, data=None):
         """Generate the camera operator report."""
         if self.curevent is not None:
-            title = u'Judges Report'
             sections = self.curevent.camera_report()
             if sections:
-                self.print_report(sections, title, u'')
+                self.print_report(sections)
 
     def race_results_points_activate_cb(self, menuitem, data=None):
         """Generate the points tally report."""
         if self.curevent is not None:
-            title = u'Points Tally'
             sections = self.curevent.points_report()
             if sections:
-                self.print_report(sections, title, u'')
+                self.print_report(sections)
 
     def menu_reports_result_activate_cb(self, menuitem, data=None):
         """Generate the race result report."""
         if self.curevent is not None:
-            title = u'Result'
             sections = self.curevent.result_report()
             if sections:
-                self.print_report(sections, title, u'')
+                self.print_report(sections)
 
     ### TODO: if reports have options, this is the dialog, saved to meet
     def menu_reports_prefs_activate_cb(self, menuitem, data=None):
@@ -771,12 +788,12 @@ class roadmeet:
         rep = printing.printrep(template=tfile, path=self.configpath)
         rep.strings[u'title'] = self.title_str
         rep.strings[u'subtitle'] = self.subtitle_str
+        rep.strings[u'docstr'] = self.document_str
         rep.strings[u'datestr'] = strops.promptstr(u'Date:', self.date_str)
         rep.strings[u'commstr'] = strops.promptstr(u'Chief Commissaire:',
                                                   self.commissaire_str)
         rep.strings[u'orgstr'] = strops.promptstr(u'Organiser:',
                                                   self.organiser_str)
-        rep.strings[u'docstr'] = u''
         if self.distance:
             rep.strings[u'diststr'] = strops.promptstr(u'Distance:',
                                              unicode(self.distance) + u' km')
@@ -1053,6 +1070,7 @@ class roadmeet:
         cw.set(u'meet', u'shortname', self.shortname)
         cw.set(u'meet', u'title', self.title_str)
         cw.set(u'meet', u'subtitle', self.subtitle_str)
+        cw.set(u'meet', u'document', self.document_str)
         cw.set(u'meet', u'date', self.date_str)
         cw.set(u'meet', u'organiser', self.organiser_str)
         cw.set(u'meet', u'commissaire', self.commissaire_str)
@@ -1102,6 +1120,7 @@ class roadmeet:
                u'shortname':None,
                u'title':u'',
                u'subtitle':u'',
+               u'document':u'',
                u'date':u'',
                u'organiser':u'',
                u'commissaire':u'',
@@ -1178,6 +1197,7 @@ class roadmeet:
         self.shortname = cr.get(u'meet', u'shortname')
         self.title_str = cr.get(u'meet', u'title')
         self.subtitle_str = cr.get(u'meet', u'subtitle')
+        self.document_str = cr.get(u'meet', u'document')
         self.date_str = cr.get(u'meet', u'date')
         self.organiser_str = cr.get(u'meet', u'organiser')
         self.commissaire_str = cr.get(u'meet', u'commissaire')
@@ -1371,6 +1391,7 @@ class roadmeet:
         self.shortname = None
         self.title_str = u''
         self.subtitle_str = u''
+        self.document_str = u''
         self.date_str = u''
         self.organiser_str = u''
         self.commissaire_str = u''
