@@ -17,7 +17,7 @@
 
 """Abstract and specific classes for scoreboard 'windows'.
 
-This module provides a number of animated scoreboard window
+This module provides a number of animated plaintext scoreboard window
 objects for the display of lists, times and transitions.
 
 A scoreboard window is a stateful information block that
@@ -66,7 +66,7 @@ DATE_FMT=('%a %d/%m/%y')
 
 def get_dateline():
     return (time.strftime(DATE_FMT)
-            + ' ' * (metarace.SCB_LINELEN - 22)
+            + u' ' * (metarace.SCB_LINELEN - 22)
             + tod.tod('now').meridian())
 
 class scbwin(object):
@@ -81,8 +81,6 @@ class scbwin(object):
         self.paused = False
         self.scb = scb
         self.count = 0
-        #if type(self.scb) is not sender.sender:
-            #raise TypeError('scb param must be a sender type')
 
     def reset(self):
         """Reset scbwin to initial state."""
@@ -124,16 +122,16 @@ class scbclock(scbwin):
            CENTERED LINE 3
 
     """
-    def __init__(self, scb=None, line1='', line2='', line3=''):
+    def __init__(self, scb=None, line1=u'', line2=u'', line3=u''):
         scbwin.__init__(self, scb)
         self.line1 = line1
         self.line2 = line2
         self.line3 = line3
         self.header = get_dateline()
         self.tovr = unt4.OVERLAY_4LINE
-        if self.line3 == '':
-            if self.line2 == '':
-                if self.line1 == '':
+        if self.line3 == u'':
+            if self.line2 == u'':
+                if self.line1 == u'':
                     self.tovr = unt4.OVERLAY_1LINE
                 else:
                     self.tovr = unt4.OVERLAY_2LINE
@@ -188,20 +186,20 @@ class scbtt(scbwin):
         >>>>>>>>(3) hh:mm:ss.dcm 
 
     """
-    def __init__(self, scb=None, header='',line1='', line2=''):
+    def __init__(self, scb=None, header=u'',line1=u'', line2=u''):
         scbwin.__init__(self, scb)
         self.header = header
         self.line1 = line1
         self.line2 = line2
         self.nextline2 = line2
-        self.curt1 = ''
-        self.nextt1 = ''
-        self.curr1 = ''
-        self.nextr1 = ''
-        self.curt2 = ''
-        self.nextt2 = ''
-        self.curr2 = ''
-        self.nextr2 = ''
+        self.curt1 = u''
+        self.nextt1 = u''
+        self.curr1 = u''
+        self.nextr1 = u''
+        self.curt2 = u''
+        self.nextt2 = u''
+        self.curr2 = u''
+        self.nextr2 = u''
 
     def redraw(self):
         for i in range(4,10):
@@ -211,32 +209,32 @@ class scbtt(scbwin):
         self.scb.setline(6, self.line1)
         self.scb.setline(8, self.line2)
         self.nextline2 = self.line2
-        self.curt1 = ''
-        self.nextt1 = ''
-        self.curr1 = ''
-        self.nextr1 = ''
-        self.curt2 = ''
-        self.nextt2 = ''
-        self.curr2 = ''
-        self.nextr2 = ''
+        self.curt1 = u''
+        self.nextt1 = u''
+        self.curr1 = u''
+        self.nextr1 = u''
+        self.curt2 = u''
+        self.nextt2 = u''
+        self.curr2 = u''
+        self.nextr2 = u''
 
-    def setline2(self, line2str=''):
+    def setline2(self, line2str=u''):
         """Replace the line 2 text."""
         self.nextline2 = line2str
  
-    def sett1(self, timestr=''):
+    def sett1(self, timestr=u''):
         """Set the next front straight time string."""
         self.nextt1 = timestr
 
-    def sett2(self, timestr=''):
+    def sett2(self, timestr=u''):
         """Set the next back straight time string."""
         self.nextt2 = timestr
 
-    def setr1(self, rank=''):
+    def setr1(self, rank=u''):
         """Set the next front straight rank string."""
         self.nextr1 = rank
 
-    def setr2(self, rank=''):
+    def setr2(self, rank=u''):
         """Set the next back straight rank string."""
         self.nextr2 = rank
 
@@ -246,7 +244,7 @@ class scbtt(scbwin):
             if self.curr1 != self.nextr1:
                 self.scb.setline(7,
                       strops.truncpad(self.nextr1, metarace.SCB_LINELEN - 13,
-                                      'r') + ' ' + self.nextt1)
+                                      'r') + u' ' + self.nextt1)
                 self.curr1 = self.nextr1
                 self.curt1 = self.nextt1
             elif self.curt1 != self.nextt1:
@@ -255,7 +253,7 @@ class scbtt(scbwin):
             if self.curr2 != self.nextr2:
                 self.scb.setline(9,
                       strops.truncpad(self.nextr2, metarace.SCB_LINELEN - 13,
-                                      'r') + ' ' + self.nextt2)
+                                      'r') + u' ' + self.nextt2)
                 self.curr2 = self.nextr2
                 self.curt2 = self.nextt2
             elif self.curt2 != self.nextt2:
@@ -284,17 +282,17 @@ class scbtimer(scbwin):
                Avg:  xx.yyy km/h
 
     """
-    def __init__(self, scb=None, line1='', line2='',
-                 timepfx='', avgpfx='Avg:'):
+    def __init__(self, scb=None, line1=u'', line2=u'',
+                 timepfx=u'', avgpfx=u'Avg:'):
         scbwin.__init__(self, scb)
         self.line1 = line1
         self.line2 = line2
         self.timepfx = timepfx
         self.avgpfx = avgpfx
-        self.curtime = ''
-        self.nexttime = ''
-        self.curavg = ''
-        self.nextavg = ''
+        self.curtime = u''
+        self.nexttime = u''
+        self.curavg = u''
+        self.nextavg = u''
 
     def redraw(self):
         for i in range(4,10):
@@ -304,16 +302,16 @@ class scbtimer(scbwin):
         self.scb.setline(5, self.line2)
         self.scb.setline(6, strops.truncpad(self.timepfx, 
                              metarace.SCB_LINELEN - 13, 'r'))
-        self.curtime = ''
-        self.nexttime = ''
-        self.curavg = ''
-        self.nextavg = ''
+        self.curtime = u''
+        self.nexttime = u''
+        self.curavg = u''
+        self.nextavg = u''
 
-    def settime(self, timestr=''):
+    def settime(self, timestr=u''):
         """Set the next time speed string."""
         self.nexttime = timestr
 
-    def setavg(self, avgstr=''):
+    def setavg(self, avgstr=u''):
         """Set the next average speed string."""
         self.nextavg = avgstr
 
@@ -327,7 +325,7 @@ class scbtimer(scbwin):
             if self.curavg != self.nextavg:
                 self.scb.setline(7,
                       strops.truncpad(self.avgpfx, metarace.SCB_LINELEN - 13,
-                                       'r') + ' ' + self.nextavg)
+                                       'r') + u' ' + self.nextavg)
                 self.curavg = self.nextavg
             self.count += 1
 
@@ -369,19 +367,19 @@ class scbintro(scbwin):
                 self.paused = True
             self.count += 1
 
-    def setinfo(self, prompt='', info='', xtra=''):
+    def setinfo(self, prompt=u'', info=u'', xtra=u''):
         """Update overlay info."""
-        self.prompt = str(prompt)[0:32]
-        self.info = str(info)[0:32]
-        self.xtra = str(xtra)[0:32]
+        self.prompt = prompt[0:32]
+        self.info = info[0:32]
+        self.xtra = xtra[0:32]
 
-    def __init__(self, scb=None, head='', lines=3):
+    def __init__(self, scb=None, head=u'', lines=3):
         scbwin.__init__(self, scb)
         self.header = head
         self.lines = 3
-        self.prompt = ''
-        self.info = ''
-        self.xtra = ''
+        self.prompt = u''
+        self.info = u''
+        self.xtra = u''
         self.tovr = unt4.OVERLAY_3LINE
         if lines != 3:
             self.lines = 4
@@ -391,7 +389,6 @@ class logoanim(scbwin):
     """Animated 'logo' screen."""
     def redraw(self):
         pass
-        #self.scb.setoverlay(unt4.OVERLAY_IMAGE)
 
     def update(self):
         if not self.paused:
@@ -408,7 +405,7 @@ class logoanim(scbwin):
 
                  # Set image content
                  curidx = (self.count//self.delay) % len(self.llist)
-                 if self.llist[curidx] == 'CLOCK':
+                 if self.llist[curidx] == u'CLOCK':
                      overlay = unt4.OVERLAY_CLOCK
                  else:
                      self.scb.setline(dbline, self.llist[curidx]) # set img
@@ -424,9 +421,9 @@ class logoanim(scbwin):
         for l in logostr.split():
             self.llist.append(l)
         if len(self.llist) == 0:
-            self.llist.append('')	# ensure one entry
+            self.llist.append(u'')	# ensure one entry
  
-    def __init__(self, scb=None, logolist='', delay=100):
+    def __init__(self, scb=None, logolist=u'', delay=100):
         scbwin.__init__(self, scb)
         self.curpg = 0
         self.llist = []
@@ -437,7 +434,7 @@ class scbtest(scbwin):
     """A "test pattern" that loops over all the overlays."""
     def redraw(self):
         for i in range(0,19):
-            self.scb.setline(i, 'Line ' + str(i)) 
+            self.scb.setline(i, u'Line ' + unicode(i)) 
 
     def update(self):
         if not self.paused:
@@ -446,7 +443,7 @@ class scbtest(scbwin):
                  self.curov = (self.curov + 1) % 4
             self.count += 1
 
-    def __init__(self, scb=None, head='', lines=3):
+    def __init__(self, scb=None, head=u'', lines=3):
         scbwin.__init__(self, scb)
         self.ovrs = [unt4.OVERLAY_4LINE, unt4.OVERLAY_R2P4, unt4.OVERLAY_24X6,
                      unt4.OVERLAY_IMAGE]
@@ -463,18 +460,17 @@ class scbintsprint(scbwin):
         self.rows=[]
         if coldesc is not None and rows is not None:
             for row in rows:
-                nr = ''
+                nr = u''
                 oft = 0
                 for col in coldesc:
-                    if type(col) is str:
+                    if type(col) is unicode:	# assume all cols uni
                         nr += col
                     else:
                         if len(row) > oft:	# space pad 'short' rows
                             nr += strops.truncpad(row[oft], col[0], col[1])
                         else:
-                            nr += ' ' * col[0]
+                            nr += u' ' * col[0]
                         oft += 1
-                   
                 self.rows.append(nr[0:32])
         self.nrpages = len(self.rows)//self.pagesz + 1
         if self.nrpages > 1 and len(self.rows) % self.pagesz == 0:
@@ -482,7 +478,7 @@ class scbintsprint(scbwin):
         # avoid hanging residual by scooting 2nd last entry onto
         # last page with a 'dummy' row, or scoot single line down by one
         if len(self.rows) % self.pagesz == 1:
-            self.rows.insert(len(self.rows) - 2, ' ')
+            self.rows.insert(len(self.rows) - 2, u' ')
 
     def redraw(self):
         for i in range(4,10):
@@ -510,7 +506,7 @@ class scbintsprint(scbwin):
         if not self.paused:
             self.count += 1
 
-    def __init__(self, scb=None, line1='', line2='',
+    def __init__(self, scb=None, line1=u'', line2=u'',
                  coldesc=None, rows=None, delay=PAGE_DELAY):
         scbwin.__init__(self, scb)
         self.pagesz = 4
@@ -551,16 +547,16 @@ class scbtable(scbwin):
         self.rows=[]
         if coldesc is not None and rows is not None:
             for row in rows:
-                nr = ''
+                nr = u''
                 oft = 0
                 for col in coldesc:
-                    if type(col) is str:
+                    if type(col) is unicode:
                         nr += col
                     else:
                         if len(row) > oft:	# space pad 'short' rows
                             nr += strops.truncpad(row[oft], col[0], col[1])
                         else:
-                            nr += ' ' * col[0]
+                            nr += u' ' * col[0]
                         oft += 1
                 self.rows.append(nr)	# truncation in sender ok
         self.nrpages = len(self.rows)//self.pagesz + 1
@@ -569,7 +565,7 @@ class scbtable(scbwin):
         # avoid hanging residual by scooting 2nd last entry onto
         # last page with a 'dummy' row, or scoot single line down by one
         if len(self.rows) % self.pagesz == 1:
-            self.rows.insert(len(self.rows) - 2, ' ')
+            self.rows.insert(len(self.rows) - 2, u' ')
 
         # if time field set and not a round number of rows, append
         # time line to last row of last page
@@ -577,11 +573,11 @@ class scbtable(scbwin):
         if self.timestr is not None and finalmod != 0:
             padrows = (self.pagesz - 1) - finalmod
             while padrows > 0:
-                self.rows.append(' ')
+                self.rows.append(u' ')
                 padrows -= 1
             self.rows.append(strops.truncpad(self.timepfx,
                                   metarace.SCB_LINELEN - 13, 'r')
-                                      + ' ' + self.timestr[0:12])
+                                      + u' ' + self.timestr[0:12])
 
     def redraw(self):
         for i in range(10,18):
@@ -608,9 +604,9 @@ class scbtable(scbwin):
         if not self.paused:
             self.count += 1
 
-    def __init__(self, scb=None, head='',
+    def __init__(self, scb=None, head=u'',
                  coldesc=None, rows=None, pagesz=7,
-                 timepfx='', timestr=None, delay=PAGE_DELAY):
+                 timepfx=u'', timestr=None, delay=PAGE_DELAY):
         scbwin.__init__(self, scb)
         # set page size
         self.pagesz = 7
