@@ -18,8 +18,8 @@
 """DISC/DHI sender class.
 
 This module provides a thread object which collects, queues
-and dispatches all messages intended for the scoreboard to
-the DHI. A calling application should use the sender methods
+and dispatches all messages intended for a galactica scoreboard
+with DHI. A calling application should use the sender methods
 for all low-level scb drawing.
 
 SCB messages are stored in a Queue object and written out to
@@ -35,6 +35,10 @@ import socket
 from metarace import unt4
 from metarace import strops
 
+# Default Galactica encoding is cp1252 (ansi)
+#ENCODING = 'ascii'
+ENCODING = 'cp1252'
+
 # dispatch thread queue commands
 TCMDS = ('EXIT', 'PORT', 'MSG')
 
@@ -96,23 +100,23 @@ def mkport(port):
 
     """
     nprot = socket.SOCK_DGRAM	# default is UDP
-    naddr = 'localhost'		# default is localhost
+    naddr = u'localhost'	# default is localhost
     nport = 5060		# default is 'sip' scbport
-    if port == 'DISC':
+    if port == u'DISC':
         nprot = socket.SOCK_STREAM
-        naddr = '192.168.96.32'
+        naddr = u'192.168.1.212'	# specific to DISC velodrome
         nport = 16372
-    elif port == 'DEBUG':
+    elif port == u'DEBUG':
         pass
     else:
-        vels = ['UDP', 'localhost', 'sip']
-        aels = port.translate(strops.PRINT_TRANS).strip().split(':')
+        vels = [u'UDP', u'localhost', u'sip']
+        aels = port.translate(strops.PRINT_UTRANS).strip().split(u':')
         if len(aels) == 3:
             vels[0] = aels[0].upper()
             vels[1] = aels[1]
             vels[2] = aels[2]
         elif len(aels) == 2:
-            if aels[0].upper() in ['TCP', 'UDP']:
+            if aels[0].upper() in [u'TCP', u'UDP']:
                 # assume PROT:ADDR
                 vels[0] = aels[0].upper()
                 vels[1] = aels[1]
@@ -125,9 +129,9 @@ def mkport(port):
             raise socket.error('Invalid port specification string')
 
         # 'import' the vels...
-        if vels[0] == 'TCP':
+        if vels[0] == u'TCP':
             nprot = socket.SOCK_STREAM
-        elif vels[0] == 'UDP':
+        elif vels[0] == u'UDP':
             nprot = socket.SOCK_DGRAM
         else:
             raise socket.error('Invalid protocol specified.')
@@ -149,7 +153,7 @@ class sender(threading.Thread):
     text drawing primitives, overlay control and clearing.
 
     Scoreboard DHI database is assumed to comprise 20 rows
-    (lines) of 32 latin_1 characters (columns). Mapping of
+    (lines) of 32 ansi (cp1252) characters (columns). Mapping of
     database rows to overlay screens is outlined in the attached
     DISC DHI documentation.
 
@@ -166,17 +170,16 @@ class sender(threading.Thread):
     def setline(self, line, msg):
         """Set the specified DHI database line to msg."""
         msg = msg[0:self.linelen].ljust(self.linelen)
-        msg = msg + ' ' * (self.linelen - len(msg))
         self.sendmsg(unt4.unt4(xx=0,yy=int(line),text=msg))
 
-    def linefill(self, line, char='_'):
+    def linefill(self, line, char=u'_'):
         """Use char to fill the specified line."""
         msg = char * self.linelen
         self.sendmsg(unt4.unt4(xx=0,yy=int(line),text=msg))
 
     def postxt(self, line, oft, msg):
         """Position msg at oft on line in DHI database."""
-        assert oft >= 0, 'Offset should be >= 0'
+        # TODO: Handle negative offsets? From right?
         if oft < self.linelen:
             msg = msg[0:(self.linelen-oft)]
             self.sendmsg(unt4.unt4(xx=int(oft),yy=int(line),text=msg))
@@ -190,7 +193,7 @@ class sender(threading.Thread):
     def __init__(self, port=None, linelen=32):
         """Constructor."""
         threading.Thread.__init__(self) 
-        self.name = 'sender'
+        self.name = u'sender'
         self.port = None
         self.linelen = int(linelen)
         self.ignore = False
@@ -228,7 +231,7 @@ class sender(threading.Thread):
 
         Or use system defaults:
 
-		DISC  -- TCP:scb.disc:17372
+		DISC  -- TCP:192.168.96.32:16372
 		DEBUG -- UDP:localhost:5060
 
         """
@@ -262,42 +265,46 @@ class sender(threading.Thread):
             self.queue.task_done()
             try:
                 if m[0] == 'MSG' and not self.ignore and self.port:
-                    self.port.sendall(m[1])
+                    self.port.sendall(m[1].encode(ENCODING,'replace'))
                 elif m[0] == 'EXIT':
-                    self.log.debug('Request to close : ' + str(m[1]))
+                    self.log.debug(u'Request to close : ' + str(m[1]))
                     self.running = False
                 elif m[0] == 'PORT':
                     if self.port is not None:
                         self.port.close()
                         self.port = None
                     if m[1] is not None and m[1] != '' and m[1] != 'NULL':
-                        self.log.debug('Re-Connect port: ' + str(m[1]))
+                        self.log.debug(u'Re-Connect port: ' + str(m[1]))
                         self.port = mkport(m[1])
                         self.curov = None
                     else:
-                        self.log.debug('Not connected.')
+                        self.log.debug(u'Not connected.')
 
             except IOError as e:
-                self.log.error('IO Error: ' + str(type(e)) + str(e))
+                self.log.error(u'IO Error: ' + str(type(e)) + str(e))
                 if self.port is not None:
                     self.port.close()
                 self.port = None
             except Exception as e:
-                self.log.error('Exception: ' + str(type(e)) + str(e))
+                self.log.error(u'Exception: ' + str(type(e)) + str(e))
         if self.port is not None:
             self.port.close()
-        self.log.info('Exiting')
+        self.log.info(u'Exiting')
 
 if __name__ == "__main__":
     """Simple 'Hello World' example with logging."""
     h = logging.StreamHandler()
     h.setLevel(logging.DEBUG)
-    s = sender('DEBUG')
+    s = sender('DISC')
     s.log.addHandler(h)
-    s.clrall()				# queue commands
-    s.setline(0, 'Hello World')
-    s.setoverlay(unt4.OVERLAY_1LINE)
     s.start()				# start thread
+    s.clrall()				# queue commands
+    s.setline(0, u'HHH\u00e9llo W\u00fcrld')
+    s.setline(1, u'HHH\u00e9llo W\u00fcrld')
+    s.setline(6, u'HHH\u00e9llo W\u00fcrld')
+    s.setline(7, u'HHH\u00e9llo W\u00fcrld')
+    s.setline(8, u'HHH\u00e9llo W\u00fcrld')
+    s.setoverlay(unt4.OVERLAY_2LINE)
     s.wait()				# wait for all cmds to be proc'd
     if s.connected():
         print('- sender still connected.')
