@@ -250,6 +250,9 @@ DEFPORT = '/dev/ttyUSB0'
 # Serial baudrate
 THBC_BAUD = 19200
 
+# GTK Priority for timing message callbacks sent to main loop
+THBC_PRIORITY = glib.PRIORITY_HIGH
+
 # UDP Port number for ethernet connection
 THBC_UDP_PORT = 2008
 
@@ -287,9 +290,11 @@ RFID_LOG_LEVEL = 16     # lower so not in status and on-screen logger.
 logging.addLevelName(RFID_LOG_LEVEL, 'RFID')
 
 # decoder config consts
+CONFIG_LEN = 27
 CONFIG_TOD = 0
 CONFIG_GPS = 1
-CONFIG_TZ = 2
+CONFIG_TZ_HOUR = 2
+CONFIG_TZ_MIN = 3
 CONFIG_485 = 4
 CONFIG_FIBRE = 5
 CONFIG_PRINT = 6
@@ -298,12 +303,20 @@ CONFIG_PROT = 8
 CONFIG_PULSE = 9
 CONFIG_PULSEINT = 10
 CONFIG_CELLSYNC = 11
-CONFIG_CELLTOD = 12
+CONFIG_CELLTOD_HOUR = 12
+CONFIG_CELLTOD_MIN = 13
 CONFIG_LANG = 14
+CONFIG_TONE_STA = 15
+CONFIG_TONE_BOX = 17
+CONFIG_TONE_MAN = 19
+CONFIG_TONE_CEL = 21
+CONFIG_TONE_BXX = 23
+CONFIG_SPARE = 25
 CONFIG_FLAGS = {
 	CONFIG_TOD: u'Time of Day',
 	CONFIG_GPS: u'GPS Sync',
-	CONFIG_TZ: u'Timezone',
+	CONFIG_TZ_HOUR: u'Timezone Hour',
+	CONFIG_TZ_MIN: u'Timezone Min',
 	CONFIG_485: u'Distant rs485',
 	CONFIG_FIBRE: u'Distant Fibre',
 	CONFIG_PRINT: u'Serial Print',
@@ -312,8 +325,15 @@ CONFIG_FLAGS = {
 	CONFIG_PULSE: u'Sync Pulse',
 	CONFIG_PULSEINT: u'Sync Interval',
 	CONFIG_CELLSYNC: u'CELL Sync',
-	CONFIG_CELLTOD: u'CELL Sync ToD',
-	CONFIG_LANG: u'Lang Fr'
+	CONFIG_CELLTOD_HOUR: u'CELL Sync Hour',
+	CONFIG_CELLTOD_MIN: u'CELL Sync Min',
+	CONFIG_LANG: u'Lang Fr',
+        CONFIG_TONE_STA: u'STA Tone',
+        CONFIG_TONE_BOX: u'BOX Tone',
+        CONFIG_TONE_MAN: u'MAN Tone',
+        CONFIG_TONE_CEL: u'CEL Tone',
+        CONFIG_TONE_BXX: u'BXX Tone',
+        CONFIG_SPARE: u'[spare]'
 }
 
 # Initialise crc algorithm for CRC-16/MCRF4XX
@@ -332,6 +352,19 @@ def thbc_crc(msgstr='123456789'):
     """Return CRC-16/MCRF4XX on input string."""
     return crc_alg.table_driven(msgstr)
 
+def val2hexval(val):
+    """Convert int to decimal digit equivalent hex byte."""
+    ret = 0x00
+    ret |= ((val//10)&0x0f)<<4	# msd	97 -> 0x90
+    ret |= (val%10)&0x0f	# lsd   97 -> 0x07
+    return ret
+
+def hexval2val(hexval):
+    """Unconvert a decimal digit equivalent hex byte to int."""
+    ret = 10*(hexval>>4)	# tens 0x97 -> 90
+    ret += hexval&0x0f		# ones 0x97 ->  7
+    return ret
+
 class dgram(object):
     """UDP port object."""
     def __init__(self, host, port):
@@ -473,6 +506,41 @@ class thbc(threading.Thread):
         crcstr = chr(crc>>8) + chr(crc&0xff)
         self.write(ESCAPE + cmdstr + crcstr + '>')
 
+    def __serialise_config(self):
+        """Convert current decoder setting into a config string"""
+        obuf = bytearray(CONFIG_LEN)
+        # fill in 'spare' bytes
+        obuf[CONFIG_SPARE] = 0x20	# (space)
+        obuf[CONFIG_SPARE+1] = 0x20
+
+        # fill in tone values
+	for opt in [CONFIG_TONE_STA, CONFIG_TONE_BOX, CONFIG_TONE_MAN,
+                     CONFIG_TONE_CEL, CONFIG_TONE_BXX]:
+            if opt in self.decoderconfig:
+                obuf[opt] = val2hexval(self.decoderconfig[opt]//100) # xx00
+                obuf[opt+1] = val2hexval(self.decoderconfig[opt]%100) # 00xx
+
+        # fill in single byte values
+        for opt in [CONFIG_TZ_HOUR, CONFIG_TZ_MIN, CONFIG_PROT,
+                    CONFIG_PULSEINT, CONFIG_CELLTOD_HOUR, CONFIG_CELLTOD_MIN]:
+            if opt in self.decoderconfig:
+                obuf[opt] = val2hexval(self.decoderconfig[opt]%100) # ??
+
+        # fill in flags
+	for opt in [CONFIG_TOD, CONFIG_GPS, CONFIG_485, CONFIG_FIBRE,
+	            CONFIG_PRINT, CONFIG_MAX, CONFIG_PULSE,
+                    CONFIG_CELLSYNC, CONFIG_LANG]:
+            if opt in self.decoderconfig:
+                if self.decoderconfig[opt]:
+                    obuf[opt] = 0x01
+        return str(obuf)	# !! not unicode
+
+    def set_config(self):
+        """Write current configuration to decoder."""
+        cmd = chr(0x08) + chr(0x08) + self.__serialise_config()
+        self.v3_cmd(cmd)
+        self.get_config()
+       
     def set_date(self, timestruct=None):
         """Set the date on the decoder."""
         if timestruct is None:
@@ -509,16 +577,31 @@ class thbc(threading.Thread):
 
     def __parse_config(self, msg):
         # decoder configuration message.
+        ibuf = bytearray(msg)
         self.decoderconfig = {}
-        showflags = []
+        showflags = {}
         for flag in sorted(CONFIG_FLAGS):	# import all
-            if flag in [ CONFIG_TZ, CONFIG_PROT,
-                         CONFIG_PULSEINT, CONFIG_CELLTOD]:
-                pass	# TODO: Skip it for now
-            else:
-                if ord(msg[flag]):	# Time of day
-                    self.decoderconfig[flag] = True
-                    showflags.append(CONFIG_FLAGS[flag])
+            # tone values
+            if flag in [CONFIG_TONE_STA, CONFIG_TONE_BOX, CONFIG_TONE_MAN,
+                     CONFIG_TONE_CEL, CONFIG_TONE_BXX]:
+                self.decoderconfig[flag] = 100*hexval2val(ibuf[flag])
+                self.decoderconfig[flag] += hexval2val(ibuf[flag+1])
+                showflags[CONFIG_FLAGS[flag]] = self.decoderconfig[flag]
+
+            # single byte values
+            elif flag in [CONFIG_TZ_HOUR, CONFIG_TZ_MIN, CONFIG_PROT,
+                    CONFIG_PULSEINT, CONFIG_CELLTOD_HOUR, CONFIG_CELLTOD_MIN]:
+                self.decoderconfig[flag] = hexval2val(ibuf[flag])
+                showflags[CONFIG_FLAGS[flag]] = self.decoderconfig[flag]
+
+            # 'booleans'
+            elif flag in [CONFIG_TOD, CONFIG_GPS, CONFIG_485, CONFIG_FIBRE,
+                    CONFIG_PRINT, CONFIG_MAX, CONFIG_PULSE,
+                    CONFIG_CELLSYNC, CONFIG_LANG]:
+                self.decoderconfig[flag] = bool(ibuf[flag])
+                if self.decoderconfig[flag]:
+                    showflags[CONFIG_FLAGS[flag]] = True
+
         self.unitno = u''
         for c in msg[43:47]:
             self.unitno += unichr(ord(c)+ord('0'))
@@ -526,7 +609,7 @@ class thbc(threading.Thread):
         boxlvl = hex(ord(msg[26]))
 
         self.log.info(u'Decoder ID: ' + self.unitno 
-                               + '\tFlags: ' + u','.join(showflags))
+                               + '\tConfig: ' + repr(showflags))
         self.log.debug(u'Decoder Levels: STA=' + stalvl
                                + u', BOX=' + boxlvl)
 
@@ -606,7 +689,7 @@ class thbc(threading.Thread):
                 self.__rdbuf += ch	# include trailing newline
                 t = self.__parse_message(self.__rdbuf.lstrip('\0'))
                 if t is not None:
-                    glib.idle_add(self.__cb, t)
+                    glib.idle_add(self.__cb, t, priority=THBC_PRIORITY)
                 self.__rdbuf = ''
             else:
                 self.__rdbuf += ch
@@ -616,7 +699,7 @@ class thbc(threading.Thread):
         """Try to extract passing information from lines in a file."""
         t = self.__parse_message(l, False)
         if t is not None:
-            glib.idle_add(self.__cb, t)
+            glib.idle_add(self.__cb, t, priority=glib.PRIORITY_LOW)
 
     def __mkport(self, pstr):
         """Try to guess port type."""
@@ -657,7 +740,8 @@ class thbc(threading.Thread):
                     elif m[0] == 'TRIG':
                         if type(m[1]) is tod.tod:
                             self.log.log(RFID_LOG_LEVEL, str(m[1]))
-                            glib.idle_add(self.__cb, m[1])
+                            glib.idle_add(self.__cb, m[1],
+                                          priority=THBC_PRIORITY)
                     elif m[0] == 'SYNC':
                         t = tod.tod('now')
                         # DANGER: Busy wait may interfere with caller
@@ -715,6 +799,28 @@ def showstatus(data=None):
     data.status()
     return True
 
+def doconfig(t):
+    print 'CONFIG'
+    t.decoderconfig[CONFIG_MAX] = False
+    t.decoderconfig[CONFIG_485] = False
+    t.decoderconfig[CONFIG_PULSE] = True
+    t.decoderconfig[CONFIG_PULSEINT] = 1
+    t.decoderconfig[CONFIG_CELLSYNC] = True
+    t.decoderconfig[CONFIG_CELLTOD_HOUR] = 0
+    t.decoderconfig[CONFIG_CELLTOD_MIN] = 0
+    t.set_config()
+    return False
+
+def dostart(t):
+    t.start_session()
+    print 'START'
+    return False
+
+def dostop(t):
+    t.stop_session()
+    print 'STOP'
+    return False
+
 if __name__ == "__main__":
     import metarace
     import gtk
@@ -729,13 +835,19 @@ if __name__ == "__main__":
     t.log.addHandler(lh)
     try:
         t.start()
-        t.setport(u'192.168.95.252')
+        #t.setport(u'192.168.95.252')
+        t.setport(u'/dev/ttyUSB0')
         t.sane()
-        t.set_date()
-        t.sync()
+        t.setlvl(u'00', u'00')
+        #t.set_date()
+        #t.sync()
         t.setcb(printtag)
-        glib.timeout_add_seconds(5, showstatus, t)
-        t.start_session()
+        #t.stop_session()
+        #glib.timeout_add_seconds(5, doconfig, t)
+        #glib.timeout_add_seconds(4, dostop, t)
+        #glib.timeout_add_seconds(6, doconfig, t)
+        #glib.timeout_add_seconds(15, dostart, t)
+        #t.start_session()
         gtk.main()
     except:
         t.stop_session()
